==================================
Welcome to Ironic Inspector Client
==================================

This is a client library and tool for `Ironic Inspector`_.

Contents
========

.. toctree::
   :maxdepth: 2

   cli/index
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Ironic Inspector: https://docs.openstack.org/ironic-inspector/latest/

